ACENITE_URL   = "http://localhost:8000/server"

ALLOWED_FRAMEWORKS = {
    "flask",
    "fastapi",
    "django",
}

ALLOWED_INSTRUMENTATIONS = {
    "requests",
    "httpx",
    "psycopg2",
    "sqlalchemy",
}
